pub struct CleanReport {
pub removed: Vec<Candidate>,
pub quarantined: Vec<QuarantineEntry>,
pub failures: Vec<String>,
pub removed_bytes: u64,
pub quarantined_bytes: u64,
}Expand description
Outcome of deleting a validated scan report.
Fields
removed: Vec<Candidate>Candidates removed successfully.
quarantined: Vec<QuarantineEntry>Candidates moved into persistent safety holds instead of being deleted.
failures: Vec<String>Candidate-specific failures. Cleanup continues after a failure.
removed_bytes: u64Scan-time allocated bytes represented by successful removals.
quarantined_bytes: u64Bytes retained on disk until their safety holds are purged.