load_config

Function load_config 

pub fn load_config(explicit: Option<&Path>) -> Result<Config>
Loads an explicit configuration file or the first discovered default.

Errors

Returns an error when an explicit file is missing, unreadable, or invalid.