pub fn matches_custom_rule(path: &Path, rule: &CustomRule) -> boolExpand description
Revalidates a config-defined rule using exact candidate names and direct sibling markers.
pub fn matches_custom_rule(path: &Path, rule: &CustomRule) -> boolRevalidates a config-defined rule using exact candidate names and direct sibling markers.