pub fn contains_git_tracked_files(path: &Path) -> Result<bool>
Returns true when Git tracks the candidate itself or any content below it.
Returns an error when Git is installed but cannot inspect an applicable repository.