Skip to main contentModule scanner
Source - ScanOptions
- Scanner configuration.
- LearningMode
- Controls whether the scanner emits local growth observations.
- classify
- Classifies a directory using conservative, filesystem-verifiable markers.
- default_roots
- Returns useful development roots without scanning the entire home directory.
- expensive_global_cache_paths
- Returns the exact allowlist for caches that can be expensive to download again.
- global_cache_paths
- Returns the exact allowlist for package and tool caches that are cheap to restore.
- scan
- Scans configured roots without modifying the filesystem.
- totals_by_category
- Groups candidate bytes by category.